{% extends "template/template.html" %}
{% block title%}{{report.title}}{% endblock %}
{% block content %}
<h1>{{report.title}}</h1>
<FORM METHOD="POST">
<TABLE BORDER="0">
    {{report.form.as_table}}
</TABLE>
<INPUT TYPE="submit" />
</FORM>
{% endblock %}
