{% extends "template/template.html" %}
{% block title%}500. Server error{% endblock %}
{% block content %}
<h1>500. Server error</h1>
Unexpected error in program. Error reported to administrator and will be fixed soon.
Sorry for inconvenience.
{% endblock %}
