{% extends "admin/change_list.html" %}
{% block object-tools %}
{% if has_add_permission %}
<ul class="object-tools"><li><a href="/fm/upload_mib/" class="addlink">Upload MIB</a></li></ul>
{% endif %}
{% endblock %}
