@import url("/media/css/dashboard.css");

#footer {
	text-align: center;
}

#content {
    margin-left: 204px;
}

div.breadcrumbs {
    margin-left: 204px;
}

ul.messagelist {
    margin-left: 204px;
}