html {
    margin: 0;
    padding: 0;
    background: #FFFFFF;
    text-align: left;
    height: 100%;
    font:12px/1.4em Verdana,sans-serif;
}

body {
    margin: 0;
    padding: 0;
    background: #F0F0F0;
    margin: 0px auto;
    padding: 0px;
    width: 300px;
    height: 150px;
    margin-top: 200px;
    font:12px/1.4em Verdana,sans-serif;
}

#footer {
    position: relative;
    padding: 4px;
    border: 0px;
    text-align: center;
    clear: both;
}

#caption {
    color: red;
    text-align: center;
    font: 30px Verdana,sans-serif;
    padding: 0px;
    margin: 0px;
}

#error {
    padding: 4px;
    color: red;
    text-align: center;
}

LABEL {
    color: red;
    padding-left: 8px;
}

#content {
    margin-left: 0px;
}

#menu {
    display: none;
}

#container {
    min-width: 308px;
    width: 308px;
}
